aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--keyboards/ergodox/ez/ez.c42
-rw-r--r--keyboards/ergodox/ez/matrix.c3
-rw-r--r--keyboards/ergodox/keymaps/familiar/README.md4
-rw-r--r--keyboards/ergodox/keymaps/familiar/keymap.c64
4 files changed, 56 insertions, 57 deletions
diff --git a/keyboards/ergodox/ez/ez.c b/keyboards/ergodox/ez/ez.c
index 3e19f2302..55b51f6fa 100644
--- a/keyboards/ergodox/ez/ez.c
+++ b/keyboards/ergodox/ez/ez.c
@@ -22,30 +22,30 @@ void matrix_init_kb(void) {
PORTD |= (1<<5 | 1<<4);
PORTE |= (1<<6);
- ergodox_blink_all_leds();
+ //ergodox_blink_all_leds();
matrix_init_user();
}
-void ergodox_blink_all_leds(void)
-{
- ergodox_led_all_off();
- ergodox_led_all_set(LED_BRIGHTNESS_HI);
- ergodox_right_led_1_on();
- _delay_ms(50);
- ergodox_right_led_2_on();
- _delay_ms(50);
- ergodox_right_led_3_on();
- _delay_ms(50);
- ergodox_right_led_1_off();
- _delay_ms(50);
- ergodox_right_led_2_off();
- _delay_ms(50);
- ergodox_right_led_3_off();
- //ergodox_led_all_on();
- //_delay_ms(333);
- ergodox_led_all_off();
-}
+// void ergodox_blink_all_leds(void)
+// {
+// ergodox_led_all_off();
+// ergodox_led_all_set(LED_BRIGHTNESS_HI);
+// ergodox_right_led_1_on();
+// _delay_ms(50);
+// ergodox_right_led_2_on();
+// _delay_ms(50);
+// ergodox_right_led_3_on();
+// _delay_ms(50);
+// ergodox_right_led_1_off();
+// _delay_ms(50);
+// ergodox_right_led_2_off();
+// _delay_ms(50);
+// ergodox_right_led_3_off();
+// //ergodox_led_all_on();
+// //_delay_ms(333);
+// ergodox_led_all_off();
+// }
uint8_t init_mcp23018(void) {
mcp23018_status = 0x20;
@@ -57,7 +57,7 @@ uint8_t init_mcp23018(void) {
// cli();
if (i2c_initialized == 0) {
i2c_init(); // on pins D(1,0)
- i2c_initialized++;
+ i2c_initialized = 1;
_delay_ms(1000);
}
diff --git a/keyboards/ergodox/ez/matrix.c b/keyboards/ergodox/ez/matrix.c
index 21b60a542..a489e5b5c 100644
--- a/keyboards/ergodox/ez/matrix.c
+++ b/keyboards/ergodox/ez/matrix.c
@@ -183,7 +183,7 @@ uint8_t matrix_scan(void)
print("left side not responding\n");
} else {
print("left side attached\n");
- ergodox_blink_all_leds();
+// ergodox_blink_all_leds();
}
}
}
@@ -391,4 +391,3 @@ static void select_row(uint8_t row)
}
}
}
-
diff --git a/keyboards/ergodox/keymaps/familiar/README.md b/keyboards/ergodox/keymaps/familiar/README.md
index e4336d9b5..8db9a7712 100644
--- a/keyboards/ergodox/keymaps/familiar/README.md
+++ b/keyboards/ergodox/keymaps/familiar/README.md
@@ -1,5 +1,5 @@
# ErgoDox Familiar Layout
-Familiar layout for those who regularly switch back and forth from ErgoDox to regular QWERTY.
+Familiar layout for those who regularly switch back and forth from ErgoDox to "normal" QWERTY.
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](../../../../license_GPLv3.md../../../../license_GPLv3.md) [![standard-readme compliant](https://img.shields.io/badge/readme%20style-standard-brightgreen.svg)](https://github.com/RichardLitt/standard-readme)
@@ -50,7 +50,7 @@ $ make ergodox-ez-familiar-teensy
### Layers
1. Base Layer: QWERTY, with arrow keys at bottom right.
1. UCIS Layer: US-International symbols layer, plus —. Accessed by toggling the `INTL` layer using the UCIS key (bottom of left thumb cluster).
-1. UCIS-Shifted Layer: Making shift work for UCIS characters. An ugly workaround. Any ideas? Accessed through holding shift while the UCIS layer is active (toggles the `INSF` layer).
+1. UCIS-Shifted Layer: Making shift work for UCIS characters. An ugly workaround. Any ideas? Accessed by holding shift while the UCIS layer is active (toggles the `INSF` layer).
1. Numpad Layer: Right hand number pad. Accessed by toggling the `NUMP` layer using the NPAD key (bottom of right thumb cluster).
1. Function Layer: F1-F12, arrows on ESDF and HJKL, media player controls. Accessed by holding either FN key (center key of each thumb cluster), which toggles the `ARRW` layer. I know, I need to work on my naming conventions.
diff --git a/keyboards/ergodox/keymaps/familiar/keymap.c b/keyboards/ergodox/keymaps/familiar/keymap.c
index c5f94afda..513bb5541 100644
--- a/keyboards/ergodox/keymaps/familiar/keymap.c
+++ b/keyboards/ergodox/keymaps/familiar/keymap.c
@@ -28,13 +28,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |--------+------+------+------+------+------| END | | PGDN |------+------+------+------+------+--------|
* | (/LSFT | Z | X | C | V | B | | | | N | M | , | . | UP | )/RSFT |
* `--------+------+------+------+------+-------------' `-------------+------+------+------+------+--------'
* | LCTRL | LGUI | MENU | ' | " | | [ | ] | LEFT | DOWN | RIGHT |
* `------------------------------------' `------------------------------------'
* ,-------------. ,-------------.
- * | VOL- | VOL+ | | | |
+ * | VOL- | VOL+ | |PRTSCR| |
* ,------|------|------| |------+------+------.
- * | SPC/ |SLASH/| MUTE | |NUMLCK|WHACK/| SPC/ |
- * | ALT | MO(1)|------| |------|MO(1) | ALT |
+ * | |SLASH/| MUTE | |NUMLCK|WHACK/| |
+ * | SPC | MO(1)|------| |------|MO(1) | SPC |
* | | | LAY3 | | LAY2 | | |
* `--------------------' `--------------------'
*/
@@ -44,19 +44,19 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_TAB, KC_Q, KC_W, KC_E, KC_R, KC_T, KC_HOME,
KC_GRV, KC_A, KC_S, KC_D, KC_F, KC_G,
KC_LSPO, KC_Z, KC_X, KC_C, KC_V, KC_B, KC_END,
- KC_LCTL, KC_LGUI, KC_MENU, KC_QUOT, S(KC_QUOT),
+ KC_LCTL, KC_LGUI, KC_MENU, KC_QUOT, KC_LALT,
KC_VOLD, KC_VOLU,
KC_MUTE,
- ALT_T(KC_SPC), LT(ARRW,KC_SLSH), TG(INTL),
+ KC_SPC, LT(ARRW, KC_SLSH), TG(INTL),
// right hand
KC_7, KC_8, KC_9, KC_0, KC_MINS, KC_EQL, KC_BSPC,
KC_PGUP, KC_Y, KC_U, KC_I, KC_O, KC_P, KC_DEL,
KC_H, KC_J, KC_K, KC_L, KC_SCLN, KC_ENTER,
KC_PGDN, KC_N, KC_M, KC_COMM, KC_DOT, KC_UP, KC_RSPC,
- KC_LBRC, KC_RBRC, KC_LEFT, KC_DOWN, KC_RGHT,
- _______, _______,
+ MT(MOD_RALT, KC_LBRC), KC_RBRC, KC_LEFT, KC_DOWN, KC_RGHT,
+ KC_PSCR, _______,
KC_NLCK,
- TG(NUMP), LT(ARRW,KC_BSLS), ALT_T(KC_SPC)
+ TG(NUMP), LT(ARRW, KC_BSLS), KC_SPC
),
/* layer 1: International symbols, etc
@@ -202,7 +202,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | | | | | | | | | HOME | PGDN | END |
* `------------------------------------' `------------------------------------'
* ,-------------. ,-------------.
- * | | PAUSE| | | |
+ * | | PAUSE| |SYSREQ| |
* ,------|------|------| |------+------+------.
* | | | | |SCRLK | | |
* | | |------| |------| | |
@@ -225,7 +225,7 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
KC_LEFT, KC_DOWN, KC_UP, KC_RGHT, _______, _______,
_______, _______, _______, _______, _______, KC_PGUP, _______,
_______, _______, KC_HOME, KC_PGDN, KC_END,
- _______, _______,
+ KC_SYSREQ, _______,
KC_SLCK,
_______, _______, _______
),
@@ -242,26 +242,26 @@ void matrix_init_user(void) {
// Runs constantly in the background, in a loop.
void matrix_scan_user(void) {
- uint8_t layer = biton32(layer_state);
-
- ergodox_board_led_off();
- ergodox_right_led_1_off();
- ergodox_right_led_2_off();
- ergodox_right_led_3_off();
- switch (layer) {
- case INTL:
- case INSF:
- ergodox_right_led_1_on();
- break;
- case NUMP:
- ergodox_right_led_2_on();
- break;
- case ARRW:
- ergodox_right_led_3_on();
- break;
- default:
- // none
- break;
- }
+ // uint8_t layer = biton32(layer_state);
+ //
+ // ergodox_board_led_off();
+ // ergodox_right_led_1_off();
+ // ergodox_right_led_2_off();
+ // ergodox_right_led_3_off();
+ // switch (layer) {
+ // case INTL:
+ // case INSF:
+ // ergodox_right_led_1_on();
+ // break;
+ // case NUMP:
+ // ergodox_right_led_2_on();
+ // break;
+ // case ARRW:
+ // ergodox_right_led_3_on();
+ // break;
+ // default:
+ // // none
+ // break;
+ // }
};
@@ -28,13 +28,13 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | (/LSFT | Z | X | C | V | B | | | | N | M | , | . | UP | )/RSFT |
* `--------+------+------+------+------+-------------' `-------------+------+------+------+------+--------'
- * | LCTRL | LGUI | MENU | ' | " | | [ | ] | LEFT | DOWN | RIGHT |
+ * | LCTRL | LGUI | MENU | ' | LALT | |[/RALT| ] | LEFT | DOWN | RIGHT |
* `------------------------------------' `------------------------------------'
* ,-------------. ,-------------.